pub enum V1Event {
Ready,
Exited(Option<i32>),
FailedToPrepare(String),
FailedToStartEntrypoint(String),
FailedTimeout,
}Expand description
Enumeration of events that can occur in a container.
The events are serialized in JSON format and sent to the client.
Variants
Ready
The container is ready to use.
Exited(Option<i32>)
The container’s entrypoint has exited.
FailedToPrepare(String)
Failed to prepare the container.
FailedToStartEntrypoint(String)
Failed to start the container’s entrypoint.
FailedTimeout
Timeout occured while waiting for the container to become ready.